@@ -182,6 +182,9 @@ public:
     void setMimeTypeFilters(const QStringList &filters);
     QStringList mimeTypeFilters() const;
 
+    void setExcludeMimeTypeFilter(const QStringList &filters);
+    QStringList excludeMimeTypeFilter() const;
+
     struct RoleInfo {
         QByteArray role;
         QString translation;
@@ -199,6 +202,9 @@ public:
      */
     static QList<RoleInfo> rolesInformation();
 
+    /** set to true to hide application/x-trash files */
+    void setShowTrashMime(bool show);
+
 Q_SIGNALS:
     /**
      * Is emitted if the loading of a directory has been started. It is
@@ -217,6 +223,11 @@ Q_SIGNALS:
      */
     void directoryLoadingCompleted();
 
+    /**
+     * Is emitted when the model is being refreshed (F5 key press)
+     */
+    void directoryRefreshing();
+
     /**
      * Is emitted after the loading of a directory has been canceled.
      */
