@@ -327,7 +327,7 @@ void DolphinSearchBox::init()
 {
     // Create search box
     m_searchInput = new QLineEdit(this);
-    m_searchInput->setPlaceholderText(i18n("Search..."));
+    m_searchInput->setPlaceholderText(i18n("Search…"));
     m_searchInput->installEventFilter(this);
     m_searchInput->setClearButtonEnabled(true);
     m_searchInput->setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
@@ -534,3 +534,5 @@ bool DolphinSearchBox::isIndexingEnabled() const
     return false;
 #endif
 }
+
+#include "moc_dolphinsearchbox.cpp"
