@@ -15,29 +15,31 @@
 
 #include <KFileItem>
 
-namespace {
-    const int AdditionalInfoViewPropertiesVersion = 1;
-    const int NameRolePropertiesVersion = 2;
-    const int DateRolePropertiesVersion = 4;
-    const int CurrentViewPropertiesVersion = 4;
+namespace
+{
+const int AdditionalInfoViewPropertiesVersion = 1;
+const int NameRolePropertiesVersion = 2;
+const int DateRolePropertiesVersion = 4;
+const int CurrentViewPropertiesVersion = 4;
 
-    // String representation to mark the additional properties of
-    // the details view as customized by the user. See
-    // ViewProperties::visibleRoles() for more information.
-    const char CustomizedDetailsString[] = "CustomizedDetails";
+// String representation to mark the additional properties of
+// the details view as customized by the user. See
+// ViewProperties::visibleRoles() for more information.
+const char CustomizedDetailsString[] = "CustomizedDetails";
 
-    // Filename that is used for storing the properties
-    const char ViewPropertiesFileName[] = ".directory";
+// Filename that is used for storing the properties
+const char ViewPropertiesFileName[] = ".directory";
 }
 
-ViewProperties::ViewProperties(const QUrl& url) :
-    m_changedProps(false),
-    m_autoSave(true),
-    m_node(nullptr)
+ViewProperties::ViewProperties(const QUrl &url)
+    : m_changedProps(false)
+    , m_autoSave(true)
+    , m_node(nullptr)
 {
-    GeneralSettings* settings = GeneralSettings::self();
+    GeneralSettings *settings = GeneralSettings::self();
     const bool useGlobalViewProps = settings->globalViewProps() || url.isEmpty();
-    bool useDetailsViewWithPath = false;
+    bool useSearchView = false;
+    bool useTrashView = false;
     bool useRecentDocumentsView = false;
     bool useDownloadsView = false;
 
@@ -48,16 +50,19 @@ ViewProperties::ViewProperties(const QUrl& url) :
         m_filePath = destinationDir(QStringLiteral("global"));
     } else if (url.scheme().contains(QLatin1String("search"))) {
         m_filePath = destinationDir(QStringLiteral("search/")) + directoryHashForUrl(url);
-        useDetailsViewWithPath = true;
+        useSearchView = true;
     } else if (url.scheme() == QLatin1String("trash")) {
         m_filePath = destinationDir(QStringLiteral("trash"));
-        useDetailsViewWithPath = true;
+        useTrashView = true;
     } else if (url.scheme() == QLatin1String("recentdocuments")) {
         m_filePath = destinationDir(QStringLiteral("recentdocuments"));
         useRecentDocumentsView = true;
     } else if (url.scheme() == QLatin1String("recentlyused")) {
         m_filePath = destinationDir(QStringLiteral("recentlyused"));
         useRecentDocumentsView = true;
+    } else if (url.scheme() == QLatin1String("timeline")) {
+        m_filePath = destinationDir(QStringLiteral("timeline"));
+        useRecentDocumentsView = true;
     } else if (url.isLocalFile()) {
         m_filePath = url.toLocalFile();
 
@@ -74,10 +79,10 @@ ViewProperties::ViewProperties(const QUrl& url) :
         }
 
         if (useDestinationDir) {
-    #ifdef Q_OS_WIN
+#ifdef Q_OS_WIN
             // m_filePath probably begins with C:/ - the colon is not a valid character for paths though
-            m_filePath =  QDir::separator() + m_filePath.remove(QLatin1Char(':'));
-    #endif
+            m_filePath = QDir::separator() + m_filePath.remove(QLatin1Char(':'));
+#endif
             m_filePath = destinationDir(QStringLiteral("local")) + m_filePath;
         }
 
@@ -93,27 +98,43 @@ ViewProperties::ViewProperties(const QUrl& url) :
 
     // If the .directory file does not exist or the timestamp is too old,
     // use default values instead.
-    const bool useDefaultProps = (!useGlobalViewProps || useDetailsViewWithPath) &&
-                                 (!QFile::exists(file) ||
-                                  (m_node->timestamp() < settings->viewPropsTimestamp()));
+    const bool useDefaultProps = (!useGlobalViewProps || useSearchView || useTrashView || useRecentDocumentsView || useDownloadsView)
+        && (!QFile::exists(file) || (m_node->timestamp() < settings->viewPropsTimestamp()));
     if (useDefaultProps) {
-        if (useDetailsViewWithPath) {
+        if (useSearchView) {
+            const QString path = url.path();
+
+            if (path == QLatin1String("/images")) {
+                setViewMode(DolphinView::IconsView);
+                setPreviewsShown(true);
+                setVisibleRoles({"text", "dimensions", "imageDateTime"});
+            } else if (path == QLatin1String("/audio")) {
+                setViewMode(DolphinView::DetailsView);
+                setVisibleRoles({"text", "artist", "album", "duration"});
+            } else if (path == QLatin1String("/videos")) {
+                setViewMode(DolphinView::IconsView);
+                setPreviewsShown(true);
+                setVisibleRoles({"text"});
+            } else {
+                setViewMode(DolphinView::DetailsView);
+                setVisibleRoles({"text", "path", "modificationtime"});
+            }
+        } else if (useTrashView) {
             setViewMode(DolphinView::DetailsView);
-            setVisibleRoles({"path"});
+            setVisibleRoles({"text", "path", "deletiontime"});
         } else if (useRecentDocumentsView || useDownloadsView) {
             setSortRole(QByteArrayLiteral("modificationtime"));
             setSortOrder(Qt::DescendingOrder);
+            setSortFoldersFirst(false);
+            setGroupedSorting(true);
 
             if (useRecentDocumentsView) {
                 setViewMode(DolphinView::DetailsView);
-                setVisibleRoles({QByteArrayLiteral("path")});
-            } else if (useDownloadsView) {
-                setSortFoldersFirst(false);
-                setGroupedSorting(true);
+                setVisibleRoles({"text", "path", "modificationtime"});
             }
         } else {
             // The global view-properties act as default for directories without
-            // any view-property configuration. Constructing a ViewProperties 
+            // any view-property configuration. Constructing a ViewProperties
             // instance for an empty QUrl ensures that the global view-properties
             // are loaded.
             QUrl emptyUrl;
@@ -209,7 +230,7 @@ bool ViewProperties::hiddenFilesShown() const
     return m_node->hiddenFilesShown();
 }
 
-void ViewProperties::setSortRole(const QByteArray& role)
+void ViewProperties::setSortRole(const QByteArray &role)
 {
     if (m_node->sortRole() != role) {
         m_node->setSortRole(role);
@@ -261,7 +282,7 @@ bool ViewProperties::sortHiddenLast() const
     return m_node->sortHiddenLast();
 }
 
-void ViewProperties::setVisibleRoles(const QList<QByteArray>& roles)
+void ViewProperties::setVisibleRoles(const QList<QByteArray> &roles)
 {
     if (roles == visibleRoles()) {
         return;
@@ -282,13 +303,12 @@ void ViewProperties::setVisibleRoles(const QList<QByteArray>& roles)
 
     // Add the updated values for the current view-mode
     newVisibleRoles.reserve(roles.count());
-    for (const QByteArray& role : roles) {
+    for (const QByteArray &role : roles) {
         newVisibleRoles.append(prefix + role);
     }
 
     if (oldVisibleRoles != newVisibleRoles) {
-        const bool markCustomizedDetails = (m_node->viewMode() == DolphinView::DetailsView)
-                                           && !newVisibleRoles.contains(CustomizedDetailsString);
+        const bool markCustomizedDetails = (m_node->viewMode() == DolphinView::DetailsView) && !newVisibleRoles.contains(CustomizedDetailsString);
         if (markCustomizedDetails) {
             // The additional information of the details-view has been modified. Set a marker,
             // so that it is allowed to also show no additional information without doing the
@@ -325,7 +345,7 @@ QList<QByteArray> ViewProperties::visibleRoles() const
     const int prefixLength = prefix.length();
 
     const QStringList visibleRoles = m_node->visibleRoles();
-    for (const QString& visibleRole : visibleRoles) {
+    for (const QString &visibleRole : visibleRoles) {
         if (visibleRole.startsWith(prefix)) {
             const QByteArray role = visibleRole.right(visibleRole.length() - prefixLength).toLatin1();
             if (role != "text") {
@@ -337,8 +357,7 @@ QList<QByteArray> ViewProperties::visibleRoles() const
     // For the details view the size and date should be shown per default
     // until the additional information has been explicitly changed by the user
     const bool useDefaultValues = roles.count() == 1 // "text"
-                                  && (m_node->viewMode() == DolphinView::DetailsView)
-                                  && !visibleRoles.contains(CustomizedDetailsString);
+        && (m_node->viewMode() == DolphinView::DetailsView) && !visibleRoles.contains(CustomizedDetailsString);
     if (useDefaultValues) {
         roles.append("size");
         roles.append("modificationtime");
@@ -347,7 +366,7 @@ QList<QByteArray> ViewProperties::visibleRoles() const
     return roles;
 }
 
-void ViewProperties::setHeaderColumnWidths(const QList<int>& widths)
+void ViewProperties::setHeaderColumnWidths(const QList<int> &widths)
 {
     if (m_node->headerColumnWidths() != widths) {
         m_node->setHeaderColumnWidths(widths);
@@ -360,7 +379,7 @@ QList<int> ViewProperties::headerColumnWidths() const
     return m_node->headerColumnWidths();
 }
 
-void ViewProperties::setDirProperties(const ViewProperties& props)
+void ViewProperties::setDirProperties(const ViewProperties &props)
 {
     setViewMode(props.viewMode());
     setPreviewsShown(props.previewsShown());
@@ -407,7 +426,7 @@ bool ViewProperties::exist() const
     return QFile::exists(file);
 }
 
-QString ViewProperties::destinationDir(const QString& subDir) const
+QString ViewProperties::destinationDir(const QString &subDir) const
 {
     QString path = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
     path.append("/view_properties/").append(subDir);
@@ -419,10 +438,17 @@ QString ViewProperties::viewModePrefix() const
     QString prefix;
 
     switch (m_node->viewMode()) {
-    case DolphinView::IconsView:   prefix = QStringLiteral("Icons_"); break;
-    case DolphinView::CompactView: prefix = QStringLiteral("Compact_"); break;
-    case DolphinView::DetailsView: prefix = QStringLiteral("Details_"); break;
-    default: qCWarning(DolphinDebug) << "Unknown view-mode of the view properties";
+    case DolphinView::IconsView:
+        prefix = QStringLiteral("Icons_");
+        break;
+    case DolphinView::CompactView:
+        prefix = QStringLiteral("Compact_");
+        break;
+    case DolphinView::DetailsView:
+        prefix = QStringLiteral("Details_");
+        break;
+    default:
+        qCWarning(DolphinDebug) << "Unknown view-mode of the view properties";
     }
 
     return prefix;
@@ -430,7 +456,7 @@ QString ViewProperties::viewModePrefix() const
 
 void ViewProperties::convertAdditionalInfo()
 {
-    QStringList visibleRoles;
+    QStringList visibleRoles = m_node->visibleRoles();
 
     const QStringList additionalInfo = m_node->additionalInfo();
     if (!additionalInfo.isEmpty()) {
@@ -438,8 +464,8 @@ void ViewProperties::convertAdditionalInfo()
         // to Icons_size, Details_date, ... where the suffix just represents
         // the internal role. One special-case must be handled: "LinkDestination"
         // has been used for "destination".
-        visibleRoles.reserve(additionalInfo.count());
-        for (const QString& info : additionalInfo) {
+        visibleRoles.reserve(visibleRoles.count() + additionalInfo.count());
+        for (const QString &info : additionalInfo) {
             QString visibleRole = info;
             int index = visibleRole.indexOf('_');
             if (index >= 0 && index + 1 < visibleRole.length()) {
@@ -450,7 +476,9 @@ void ViewProperties::convertAdditionalInfo()
                     visibleRole[index] = visibleRole[index].toLower();
                 }
             }
-            visibleRoles.append(visibleRole);
+            if (!visibleRoles.contains(visibleRole)) {
+                visibleRoles.append(visibleRole);
+            }
         }
     }
 
@@ -502,7 +530,7 @@ void ViewProperties::convertDateRoleToModificationTimeRole()
     update();
 }
 
-bool ViewProperties::isPartOfHome(const QString& filePath)
+bool ViewProperties::isPartOfHome(const QString &filePath)
 {
     // For performance reasons cache the path in a static QString
     // (see QDir::homePath() for more details)
@@ -515,7 +543,7 @@ bool ViewProperties::isPartOfHome(const QString& filePath)
     return filePath.startsWith(homePath);
 }
 
-QString ViewProperties::directoryHashForUrl(const QUrl& url)
+QString ViewProperties::directoryHashForUrl(const QUrl &url)
 {
     const QByteArray hashValue = QCryptographicHash::hash(url.toEncoded(), QCryptographicHash::Sha1);
     QString hashString = hashValue.toBase64();
